@@ -114,8 +114,6 @@ class QueueProxy(DataFacts, Queue):
         raise NotImplementedError
 
     def put(self,task_data, submission_data=None, depends_on=None):
-        print(dir(self.client.worker))
-
         return self.client.worker.questionTask(
                     worker_id=self.worker_id,
                     task_payload=dict(
@@ -130,8 +128,6 @@ class QueueProxy(DataFacts, Queue):
         if self.current_task is not None:
             raise CurrentTaskUnfinished(self.current_task)
 
-        print(dir(self.client.worker))
-
         r = self.client.worker.getOffer(worker_id=self.worker_id, queue=self.queue, update_expected_in_s= update_expected_in_s).response()
 
         if r.result is None:
@@ -171,8 +167,6 @@ class QueueProxy(DataFacts, Queue):
         self.logger.info("moving task %s from %s to %s", task_key, fromk, tok)
         self.logger.info("moving task uses update entry %s", repr(update_entry)[:300])
 
-        self.logger.info(dir(self.client.tasks))
-
         r = self.client.tasks.move_task(
                                       #worker_id=self.worker_id, 
                                       #queue=self.queue, 
